@@ -3,7 +3,7 @@ package Net::Async::Statsd;
 use strict;
 use warnings;
 
-our $VERSION = '0.004';
+our $VERSION = '0.005';
 
 =head1 NAME
 
@@ -11,7 +11,7 @@ Net::Async::Statsd - asynchronous API for Etsy's statsd protocol
 
 =head1 VERSION
 
-Version 0.004
+version 0.004
 
 =head1 SYNOPSIS
 
@@ -62,8 +62,8 @@ __END__
 
 =head1 AUTHOR
 
-Tom Molesworth <cpan@perlsite.co.uk>
+Tom Molesworth <TEAM@cpan.org>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2014. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2014-2016. Licensed under the same terms as Perl itself.
