@@ -1,5 +1,5 @@
 package Net::Async::Statsd::Bus;
-$Net::Async::Statsd::Bus::VERSION = '0.004';
+$Net::Async::Statsd::Bus::VERSION = '0.005';
 use strict;
 use warnings;
 
@@ -11,7 +11,7 @@ Net::Async::Statsd::Bus - event handling object
 
 =head1 VERSION
 
-Version 0.004
+version 0.004
 
 =head1 DESCRIPTION
 
@@ -35,8 +35,8 @@ __END__
 
 =head1 AUTHOR
 
-Tom Molesworth <cpan@perlsite.co.uk>
+Tom Molesworth <TEAM@cpan.org>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2014. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2014-2015. Licensed under the same terms as Perl itself.
