@@ -1,5 +1,5 @@
 package Net::Async::Statsd::Client;
-$Net::Async::Statsd::Client::VERSION = '0.004';
+$Net::Async::Statsd::Client::VERSION = '0.005';
 use strict;
 use warnings;
 
@@ -11,7 +11,7 @@ Net::Async::Statsd::Client - asynchronous API for Etsy's statsd protocol
 
 =head1 VERSION
 
-Version 0.004
+version 0.004
 
 =head1 SYNOPSIS
 
@@ -281,6 +281,7 @@ sub port { shift->{port} }
 =head2 host
 
 Statsd host to connect to.
+
 =cut
 
 sub host { shift->{host} }
@@ -368,8 +369,8 @@ __END__
 
 =head1 AUTHOR
 
-Tom Molesworth <cpan@perlsite.co.uk>
+Tom Molesworth <TEAM@cpan.org>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2014. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2014-2016. Licensed under the same terms as Perl itself.
