@@ -1,5 +1,5 @@
 package Net::Async::Statsd::Server;
-$Net::Async::Statsd::Server::VERSION = '0.004';
+$Net::Async::Statsd::Server::VERSION = '0.005';
 use strict;
 use warnings;
 
@@ -11,7 +11,7 @@ Net::Async::Statsd::Server - asynchronous server for Etsy's statsd protocol
 
 =head1 VERSION
 
-Version 0.004
+version 0.004
 
 =head1 SYNOPSIS
 
@@ -175,7 +175,7 @@ sub on_recv {
 	)->on_done(sub {
 		my ($host, $port) = @_;
 		$self->debug_printf("UDP packet received from %s", join ':', $host, $port);
-		my ($k, $v, $type_char, $rate) = $dgram =~ /^([^:]+):([^|]+)\|([^|]+)(?:\|\@(.+))?$/ or warn "Invalid dgram: $dgram";
+		my ($k, $v, $type_char, $rate) = $dgram =~ /^([^:]+):([^|]+)\|([^|]+)(?:\|\@(.+))?/ or warn "Invalid dgram: $dgram";
 		$rate ||= 1;
 		my $type = $self->type_for_char($type_char) // 'unknown';
 		$self->bus->invoke_event(
@@ -217,8 +217,8 @@ __END__
 
 =head1 AUTHOR
 
-Tom Molesworth <cpan@perlsite.co.uk>
+Tom Molesworth <TEAM@cpan.org>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2014. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2014-2016. Licensed under the same terms as Perl itself.
